%
% D_ECMWF2ROMS:  Driver script to create ROMS forcing NetCDF from ECMWF
%                ERA-5 Dataset
%
% svn $Id: d_ecmwf2roms.m 895 2018-02-11 23:15:37Z arango $
%   modified by  xiechuan     2021/10/06
%
%   Set file names. Input ERA-5 input data file names.  The data
%   was extracted for the Ross Sea and Amundsen Sea every 3-hours. 
%   The dataset was extracted in several annual files:
%   file name                       ERA5 Variables
%
%   era5_wind_XXXX.nc               time, v10u, v10v
%   era5_temp_XXXX.nc               time, t2m,d2m
%   era5_pair_XXXX.nc               time, msl
%   era5_cloud_XXXX.nc              time, tcc
%   era5_rain_XXXX.nc               time, mtpr
%   era5_aice_XXXX.nc               time, aice
%   era5_swrad_XXXX.nc              time, msdwswrf                      
%   ...
%   ERA-5 variable names:  @ denotes accumulated quantity that must
%                              be divided by the time interval into the
%                              cycle 3, 6, 9 or 12 hours
%
%    u10        m s-1                  10 metre U wind component
%    vl0        m s-1                  10 metre V wind component
%    t2m        K                      2 metre temperature
%    msl        Pa                     mean sea level pressure
%    d2m        K                      2 metre dewpoint temperature
%    tcc        nondimensional(0-1)    total cloud cover [0:1]
%    mtpr       kg m**-2 s**-1         Mean total precipitation rate
%    siconc     nondimensional(0-1)    Sea ice area fraction
%    msdwswrf   W m-2                  Mean surface downward short-wave radiation flux
%
% This dataset is written in compact way (short numbers). We need to
% convert to floating-point data and scale to ROMS units:
%
%   Uwind       (m s-1)               v10u
%   Vwind       (m s-1)               v10v
%   Tair        (Celsius)             t2m - 273.15;   (1 C = 273.15 K)
%   Pair        (milibar)             msl / 100;   (1 mb = 100 Pa) 
%   Qair        (percentage)          100 * (E/Es)
%   swrad       (W m-2)               msdwswrf 
%   cloud       (nondimesional)       tcc
%   rain        (kg m-2 s-1)          mtpr
%   aice        (nondimensional)      siconc
%
% where
%
%   Rho_w = 1000 kg m-3  (water density)
%
%   E  = 6.11 * 10.0 ^ (7.5 * d2m / (237.7 + d2m))    vapor pressure (mb)
%                                                     d2m in Celsius
%
%   Es = 6.11 * 10.0 ^ (7.5 * t2m / (237.7 + t2m))    saturation vapor
%                                                     pressure (mb)
%                                                     t2m in Celsius
%
%--------------------------------------------------------------------------

% Path to downloaded ERA-5 data files.
clc;
clear all;

Dir = fullfile(getenv('HOME'),         ...
               '..\Ross_amundsen_roms_model\atmosphere_forcing_file\A_ERA5_rawdata');
% The year of atmospheric forcing file was made
year_file = 2003;   
% Base date for ROMS forcing files: "days since 2003-01-01 00:00:00".  
mybasedate = datenum(2003,1,1,0,0,0);

% Set ROMS and ECMWF-ERA5 field NetCDF variable names for each forcing
% variable, input file name prefix, output file name. Notice that output
% forcing variables follows ROMS metadata design.
%
% If the ROMS option BULK_FLUXES is NOT activatived, we just need to
% process elements 1:5 in the structure vector (F).  Otherwise, we need
% process almost all the fields below. 

clear S F

F(1).Vname  = {'Uwind', 'u10'};
F(1).Tname  = {'wind_time', 'time'};
F(1).input  = 'era5_wind_';
F(1).output = ['RAS_forcing_',num2str(year_file),'_wind_era5.nc'];
F(1).scale  = 1.0;

F(2).Vname  = {'Vwind', 'v10'};
F(2).Tname  = {'wind_time', 'time'};
F(2).input  = 'era5_wind_';
F(2).output = ['RAS_forcing_',num2str(year_file),'_wind_era5.nc'];
F(2).scale  = 1.0;

F(3).Vname  = {'Tair', 't2m'};
F(3).Tname  = {'tair_time',  'time'};
F(3).input  = 'era5_temp_';
F(3).output = ['RAS_forcing_',num2str(year_file),'_Tair_era5.nc'];
F(3).scale  = 1.0;

F(4).Vname  = {'Pair', 'msl'};
F(4).Tname  = {'pair_time',  'time'};
F(4).input  = 'era5_pair_';
F(4).output = ['RAS_forcing_',num2str(year_file),'_Pair_era5.nc'];
F(4).scale  = 0.01;

F(5).Vname  = {'Qair', 'd2m'};          % Use temperature (t2m) and
F(5).Tname  = {'qair_time',  'time'};   % dewpoint temperature (d2m)
F(5).input  = 'era5_temp_';             % to compute relative humidity
F(5).output = ['RAS_forcing_',num2str(year_file),'_Qair_era5.nc'];
F(5).scale  = 1.0;

F(6).Vname  = {'swrad', 'msdwswrf'};
F(6).Tname  = {'srf_time',  'time'};
F(6).input  = 'era5_swrad_';
F(6).output = ['RAS_forcing_',num2str(year_file),'_swrad_era5.nc'];
F(6).scale  = 1.0;

F(7).Vname  = {'cloud', 'tcc'};
F(7).Tname  = {'cloud_time',  'time'};
F(7).input  = 'era5_cloud_';
F(7).output = ['RAS_forcing_',num2str(year_file),'_cloud_era5.nc'];
F(7).scale  = 1.0;

F(8).Vname  = {'rain', 'mtpr'};
F(8).Tname  = {'rain_time',  'time'};
F(8).input  = 'era5_rain_';
F(8).output = ['RAS_forcing_',num2str(year_file),'_rain_era5.nc'];
F(8).scale  = 1.0;

F(9).Vname  = {'aice', 'siconc'};
F(9).Tname  = {'ice_time',  'time'};
F(9).input  = 'era5_aice_';
F(9).output = ['RAS_forcing_',num2str(year_file),'_aice_era5.nc'];
F(9).scale  = 1.0;

% F(9).Vname  = {'hsnow', 'par'};
% F(9).Tname  = {'snow_time', 'time'};
% F(9).input  = 'ecmwf_era_ice_';
% F(9).output = 'gom_PAR_era.nc';
% F(9).scale  = 1;
% 
% F(10).Vname  = {'caice', 'par'};
% F(10).Tname  = {'cice_time',  'time'};
% F(10).input  = 'ecmwf_era_ice_';
% F(10).output = 'gom_PAR_era.nc';
% F(10).scale  = 1;
% Set field element in structure F to process.

doFields = 9;

% Various parameters.

spherical = true;                       % Spherical switch

% LonMin    = 115;                      % RAS left-bottom longitude
% LonMax    = 135;                      % RAS right-top   longitude
% LatMin    = 18;                       % RAS left-bottom latitude
% LatMax    = 46;                       % RAS right-top   latitude

FlipLat   = true;                       % Flip data in ERA NetCDF files
                                        % (see below information)

StrDay   = datenum(['01-Jan-',num2str(year_file)]);    % starting day to process
EndDay   = datenum(['31-Dec-',num2str(year_file)]);    % ending   day to process

nctype    = 'nc_float';                 % Input data is in single precision
Unlimited = true;                       % time dimension is umlimited in
                                        % output files

%--------------------------------------------------------------------------
% Create surface forcing NetCDF files: build creation parameters
% structure, S.  We want to create a single file for each forcing
% field.  However, the wind components "Uwind" and "Vwind" are
% saved in the same NetCDF file.
%--------------------------------------------------------------------------

Tindex       = [];
ReplaceValue = NaN;
PreserveType = true;

mode = netcdf.getConstant('CLOBBER');                    % overwrite!!!
mode = bitor(mode,netcdf.getConstant('64BIT_OFFSET'));

% The strategy here is to build manually the NetCDF metadata structure to
% facilitate creating several NetCDF file in a generic and compact way.
% This structure is similar to that returned by "nc_inq" or native Matlab
% function "ncinfo".
%
% Notice that we call the "roms_metadata" function to create the fields
% in the structure.  Then, we call "check_metadata" for fill unassigned
% values and to check for consistency.

OutFiles = {};

for n = 1:doFields

  ncname = char(F(n).output);
  Vname  = char(F(n).Vname{1});
  Tname  = char(F(n).Tname{1});
  if (n == 1)
    create_file = true;
  else
    create_file = ~any(strcmp(OutFiles, ncname));
  end
  
  OutFiles = [OutFiles, ncname];
  InpFile  = fullfile(Dir, strcat(char(F(n).input),num2str(year_file),'.nc'));
  
  if (create_file)
    disp(blanks(1));
    disp(['** Creating ROMS NetCDF forcing file: ', ncname,' **']);
    disp(blanks(1))
  end
  
  S.Filename = ncname;

  lon = nc_read(InpFile, 'longitude',                                   ...
                Tindex, ReplaceValue, PreserveType);

  lat = nc_read(InpFile, 'latitude',                                    ...
                Tindex, ReplaceValue, PreserveType);

% We want the longitude in the range from -180 to 180 instead of 0 to 360.
% Notice that the latitude is flip so the origin is at southwest corner
% of the extracted grid (LonMin,LatMin)

  ROMS_lon = lon; 
  ind = find(ROMS_lon > 180);
  if (~isempty(ind))
    ROMS_lon(ind) = ROMS_lon(ind) - 360;
  end

  if (FlipLat)
    ROMS_lat = flipud(lat);
  else
    ROMS_lat = lat;
  end

  Im = length(ROMS_lon);
  Jm = length(ROMS_lat);

  S.Attributes(1).Name      = 'type';
  S.Attributes(1).Value     = 'Atmosphere forcing file';

  S.Attributes(2).Name      = 'title';
  S.Attributes(2).Value     = ['ECMWF ERA-5 Dataset, ',  ...
                               'Ross Sea and Amundsen Sea Region'];

%   S.Attributes(3).Name      = 'history';
%   S.Attributes(3).Value     = ['Forcing file created with ',      ...
%                                which(mfilename) ' on ' date_stamp];
 
  S.Dimensions(1).Name      = 'lon';
  S.Dimensions(1).Length    = Im;
  S.Dimensions(1).Unlimited = false;

  S.Dimensions(2).Name      = 'lat';
  S.Dimensions(2).Length    = Jm;
  S.Dimensions(2).Unlimited = false;

  S.Dimensions(3).Name      = Tname;
  S.Dimensions(3).Length    = nc_constant('nc_unlimited');
  S.Dimensions(3).Unlimited = true;

  S.Variables(1) = roms_metadata('spherical');
  S.Variables(2) = roms_metadata('lon');
  S.Variables(3) = roms_metadata('lat');
  S.Variables(4) = roms_metadata(Tname, [], [], Unlimited);
  S.Variables(5) = roms_metadata(Vname, spherical, nctype, Unlimited);

% Edit the time variable 'units" attribute for the correct reference
% time and add calendar attribute.

  natts = length(S.Variables(4).Attributes);
  iatt  = strcmp({S.Variables(4).Attributes.Name}, 'units');
  S.Variables(4).Attributes(iatt).Value = ['days since ' datestr(mybasedate,31)];

  S.Variables(4).Attributes(natts+1).Name  = 'calendar';
  S.Variables(4).Attributes(natts+1).Value = 'gregorian';

% Change the dimensions of "shflux", "swflux", "sustr" or "svstr" to
% (lon,lat) dimensions to allow interpolation from a coarser grid in
% ROMS. As default, 'roms_metadata' uses ROMS native coordinates.
%
% This illustrates also how to manipulate the default metadata values set
% in 'roms_metadata'.  It has to be done before calling 'check_metadata'.

  if (strcmp(Vname, 'shflux') ||                                          ...
      strcmp(Vname, 'swflux') ||                                        ...
      strcmp(Vname, 'sustr')  ||                                        ...
      strcmp(Vname, 'svstr'))
    S.Variables(5).Dimensions(1).Name = 'lon';
    S.Variables(5).Dimensions(2).Name = 'lat';
  end
  
% Check ROMS metadata structure.  Fill unassigned fields.

  S = check_metadata(S);
  
% Create forcing NetCDF files.  Write our coordinates. Notice that
% "nc_append" is used here since we wand both wind components "Uwind"
% and "Vwind" to be in the same output NetCDF file for CF conventions.

  if (create_file)
    ncid = nc_create(S.Filename, mode, S); % create a new NetCDF file

    lon = repmat(ROMS_lon,  [1 Jm]);
    lat = repmat(ROMS_lat', [Im 1]);
  
    status = nc_write(S.Filename, 'spherical', int32(spherical));
    status = nc_write(S.Filename, 'lon',  lon);
    status = nc_write(S.Filename, 'lat',  lat);
  else
    nc_append(S.Filename, S)               % append to existing NetCDF file
  end

end

%--------------------------------------------------------------------------
% Convert forcing data to floating-point and scale to ROMS units.
%--------------------------------------------------------------------------

% This particular data set has a time coordinate in days starting
% on 1-Jan-1900.

epoch = datenum('01-Jan-1900');

% Set reference time for this application using the specified base date.

ref_time = (mybasedate - epoch);

StrYear  = str2num(datestr(StrDay, 'yyyy'));
EndYear  = str2num(datestr(EndDay, 'yyyy'));

MyRec = zeros([1 length(F)]);

disp(blanks(1));

for n = 1:doFields

    year  = StrYear;

  while (year <= EndYear)
    suffix  = strcat(num2str(year), '.nc');
    InpFile = fullfile(Dir, strcat(char(F(n).input),suffix));
    OutFile = char(F(n).output);
    Troms   = char(F(n).Tname{1});
    Tecmwf  = char(F(n).Tname{2});
    Vroms   = char(F(n).Vname{1});
    Vecmwf  = char(F(n).Vname{2});
    scale   = abs(F(n).scale);

% Determine time records to process.

    time = nc_read(InpFile, Tecmwf);
    time = time ./ 24;                              % hours to day

    StrRec = 1;
    EndRec = length(time);

% Read and write forcing fields. The forcing field are scaled to ROMS
% units.

    for Rec=StrRec:EndRec

      MyRec(n) = MyRec(n) + 1;

      mydate = datestr(epoch+time(Rec));

      disp(['** Processing: ', Vroms, '  for  ',mydate,' **']);  

      frc_time = time(Rec) - ref_time ;

      switch Vroms
        case 'Tair'
          field = nc_read(InpFile, Vecmwf, Rec);
          field = field - 273.15;                   % Kelvin to Celsius
        case 'Qair'     
          tsur  = nc_read(InpFile, 't2m', Rec);     % 2m temperature
          tdew  = nc_read(InpFile, 'd2m', Rec);     % 2m dewpoint
          tsur  = tsur - 273.15;
          tdew  = tdew - 273.15;
          E     = 6.11 .* 10.0 .^ (7.5 .* tdew ./ (237.7 + tdew));
          Es    = 6.11 .* 10.0 .^ (7.5 .* tsur ./ (237.7 + tsur));
          field = 100.0 .* (E ./ Es);            
        otherwise
          field = nc_read(InpFile, Vecmwf, Rec);
          field = field.*scale;
      end

      fieldfinal = field;

% If the scale F(n).scale is set to negative, the input ECMWF data is a
% cummulative integral in forecast cycle from hour zero.
% For steps at 6, 9 and 12 hours we must separate last 3 hours of 
% integration from previous accumulation.
% At 3 hour step don't change anything

      if (F(n).scale < 0)
        step = rem(frc_time,0.5)*24;
        if step == 3
          fieldfinal = field;
        else
          fieldfinal = field - field_previous;  % At other steps subtract
        end                                     % the previous accumulation

        frc_time = frc_time - 1.5/24 ;	        % Center forcing time on the
                                                % accumulation interval

        field_previous = field;                 % Save this accumulation
                                                % to on the next step
      end

% If appropriate, flip the data so the origin (1,1) corresponds to
% the lower-left corner (LonMin,LatMin) of the extracted region.
% ERA data is written into NetCDF files with the origin at (1,end).
% That is, the origin is the left-upper corner of the extracted grid
% (LonMin,LatMax).  Users need to check and plot the extracted data
% from the ECMWF server.

      if (FlipLat)
        fieldfinal  = fliplr(fieldfinal);
      end

% Write out data.

      status = nc_write(OutFile, Troms, frc_time, MyRec(n));
      status = nc_write(OutFile, Vroms, fieldfinal, MyRec(n));
    end

%  Advance year counter.  Recall all input files are split in annual
%  files.

    year = year + 1;

  end
end