%%  Generate boundary condition for ROMS model 
%  Usage
%  Input:  boundary variables
%  Output: ROMS boundary file
%
%  Written by Xie Chuan
%  Create date: 2021-10-11
%
clc;
clear all; 
close all; 

% ----------------------------- User Settings -----------------------------
data_year = 2003;
itide = false;     %Add a switch for tide
idye04 = true;    %Add dye 04 (use for HSSW dye)

% -------------------------------Path--------------------------------------
ROMS_grdfiles_dir='..\RAS_model\grid_file\';
ROMS_bryfiles_dir='..\RAISE_model\boundary_file\';
grdfilename=[ROMS_grdfiles_dir,'RAS_grd_32layer_new.nc'];
bryfilename=[ROMS_bryfiles_dir,'RAS_bry_',num2str(data_year),'_notide.nc'];
bryvardir='..\RAISE_model\boundary_file\B3_RAS_boundary_varibles_yearly\';
tidevardir='..\RAISE_model\boundary_file\B4_RAS_boundary_tide_files\';
%
% ---------------- S-coordinate setup ---------------
N = 32;           %  No. of vertical layers
Vtransform = 2;   %  Vertical transformation equation: 1, original; 2, new
Vstretching = 4;  %  Vstretching   Vertical stretching function:
%                    Vstretching = 1,  original (Song and Haidvogel, 1994)
%                    Vstretching = 2,  A. Shchepetkin (UCLA-ROMS, 2005)
%                    Vstretching = 3,  R. Geyer BBL refinement
%                    Vstretching = 4,  A. Shchepetkin (UCLA-ROMS, 2010)
theta_s = ncread(grdfilename,'theta_s');    % S-coordinate surface control parameter (scalar)
theta_b = ncread(grdfilename,'theta_b');    % S-coordinate bottom control parameter (scalar)
Tcline = 200; 
hc     = 200;      %  Width (m) of surface or bottom boundary layer in which
                   %  higher vertical resolution is required during
                   %  stretching (scalar)
%
% ------------ Read the grid file ------------
%
spherical = ncread(grdfilename,'spherical');
s_w = ncread(grdfilename,'s_w');
s_rho = ncread(grdfilename,'s_rho');
Cs_r = ncread(grdfilename,'Cs_r');
Cs_w = ncread(grdfilename,'Cs_w');
h = ncread(grdfilename,'h');
lon_rho = ncread(grdfilename,'lon_rho');
lat_rho = ncread(grdfilename,'lat_rho');
lon_u = ncread(grdfilename,'lon_u');
lat_u = ncread(grdfilename,'lat_u');
lon_v = ncread(grdfilename,'lon_v');
lat_v = ncread(grdfilename,'lat_v');
[Mp,Lp]=size(h);
L=Lp-1;
M=Mp-1;
Np=N+1;
% -------- grid dimensions --------   
Lm=Lp-2;      % Number of I-direction INTERIOR RHO-points
Mm=Mp-2;      % Number of J-direction INTERIOR RHO-points
% -------- grid variables --------
lon_rho_west = lon_rho(1,:);
lat_rho_west = lat_rho(1,:);
lon_rho_east = lon_rho(Mp,:);
lat_rho_east = lat_rho(Mp,:);
lon_rho_south = lon_rho(:,1);
lat_rho_south = lat_rho(:,1);
lon_rho_north = lon_rho(:,Lp);
lat_rho_north = lat_rho(:,Lp);
lon_u_west = lon_u(1,:);
lat_u_west = lat_u(1,:);
lon_u_east = lon_u(M,:);
lat_u_east = lat_u(M,:);
lon_u_south = lon_u(:,1);
lat_u_south = lat_u(:,1);
lon_u_north = lon_u(:,Lp);
lat_u_north = lat_u(:,Lp);
lon_v_west = lon_v(1,:);
lat_v_west = lat_v(1,:);
lon_v_east = lon_v(Mp,:);
lat_v_east = lat_v(Mp,:);
lon_v_south = lon_v(:,1);
lat_v_south = lat_v(:,1);
lon_v_north = lon_v(:,L);
lat_v_north = lat_v(:,L);
%
%  °汾NCļʽNETCDF4_CLASSICƼʹ 
% ------------------ Create netcdf file ----------------
disp('  Creating NC file...')
% ------------------ define dimensions -----------------
disp('      => Defining Dimensions...')
matfilename = [bryvardir,'RAS_bry_' num2str(data_year) '.mat'];
load(matfilename);
if itide
    tidefilename = [tidevardir,'RAS_bry_' num2str(data_year) '_tide.mat'];
    load(tidefilename);
end
% -----------------------------------------------------
dim_xi_rho = Lp;
dim_xi_u = L;
dim_xi_v = Lp;
dim_eta_rho = Mp;
dim_eta_u = Mp;
dim_eta_v = M; 
dim_s_rho = N;
dim_s_w = Np;
if data_year==2000||data_year==2004||data_year==2008||data_year==2012||data_year==2016
    dim_bry_time   = 366;
    dim_ocean_time = 366;   
    dim_temp_time  = 366;    
    dim_salt_time  = 366;  
    dim_zeta_time  = 366;
    dim_v2d_time   = 366;
else
    dim_bry_time   = 365;
    dim_ocean_time = 365; 
    dim_temp_time  = 365;     
    dim_salt_time  = 365; 
    dim_zeta_time  = 365;
    dim_v2d_time   = 365;
end
if itide
    [dim_zeta_time,~] = size(time_tide);
    [dim_v2d_time,~] = size(time_tide); 
end
dim_one = 1;
% 
% -------------- define Variables and attributes ---------------
disp('      => Defining Variables and Attributes...')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'spherical','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(bryfilename,'spherical','long_name','grid type logical switch')
ncwriteatt(bryfilename,'spherical','flag_values',[0  1])
ncwriteatt(bryfilename,'spherical','flag_meanings','Cartesian spherical')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'Vtransform','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(bryfilename,'Vtransform','long_name','vertical terrain-following transformation equation')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'Vstretching','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(bryfilename,'Vstretching','long_name','vertical terrain-following stretching function')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'theta_s','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(bryfilename,'theta_s','long_name','S-coordinate surface control parameter')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'theta_b','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(bryfilename,'theta_b','long_name','S-coordinate bottom control parameter')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'Tcline','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(bryfilename,'Tcline','long_name','S-coordinate surface/bottom layer width')
ncwriteatt(bryfilename,'Tcline','units','meter')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'hc','Dimensions',{'one',dim_one},'FillValue','disable');
ncwriteatt(bryfilename,'hc','long_name','S-coordinate parameter, critical depth')
ncwriteatt(bryfilename,'hc','units','meter')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'s_rho','Dimensions',{'s_rho',dim_s_rho},'FillValue','disable');
ncwriteatt(bryfilename,'s_rho','long_name','S-coordinate at RHO-points')
ncwriteatt(bryfilename,'s_rho','valid_min',-1)
ncwriteatt(bryfilename,'s_rho','valid_max',0)
ncwriteatt(bryfilename,'s_rho','positive','up')
ncwriteatt(bryfilename,'s_rho','standard_name','ocean_s_coordinate_g1')
ncwriteatt(bryfilename,'s_rho','formula_terms','s: s_rho C: Cs_r eta: zeta depth: h depth_c: hc')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'s_w','Dimensions',{'s_w',dim_s_w},'FillValue','disable');
ncwriteatt(bryfilename,'s_w','long_name','S-coordinate at W-points')
ncwriteatt(bryfilename,'s_w','valid_min',-1)
ncwriteatt(bryfilename,'s_w','valid_max',0)
ncwriteatt(bryfilename,'s_w','positive','up')
ncwriteatt(bryfilename,'s_w','standard_name','ocean_s_coordinate_g1')
ncwriteatt(bryfilename,'s_w','formula_terms','s: s_w C: Cs_w eta: zeta depth: h depth_c: hc')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'Cs_r','Dimensions',{'s_rho',dim_s_rho},'FillValue','disable');
ncwriteatt(bryfilename,'Cs_r','long_name','S-coordinate stretching function at RHO-points')
ncwriteatt(bryfilename,'Cs_r','valid_min',-1)
ncwriteatt(bryfilename,'Cs_r','valid_max',0)
% %--------------------------------------------------------------------------
nccreate(bryfilename,'Cs_w','Dimensions',{'s_w',dim_s_w},'FillValue','disable');
ncwriteatt(bryfilename,'Cs_w','long_name','S-coordinate stretching function at W-points')
ncwriteatt(bryfilename,'Cs_w','valid_min',-1)
ncwriteatt(bryfilename,'Cs_w','valid_max',0)
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_rho_west','Dimensions',{'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(bryfilename,'lon_rho_west','long_name','longitude of RHO-points, western boundary condition')
ncwriteatt(bryfilename,'lon_rho_west','units','degree_east')
ncwriteatt(bryfilename,'lon_rho_west','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_rho_west','Dimensions',{'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(bryfilename,'lat_rho_west','long_name','latitute of RHO-points, western boundary condition')
ncwriteatt(bryfilename,'lat_rho_west','units','degree_north')
ncwriteatt(bryfilename,'lat_rho_west','standard_name','latitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_rho_east','Dimensions',{'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(bryfilename,'lon_rho_east','long_name','longitude of RHO-points, eastern boundary condition')
ncwriteatt(bryfilename,'lon_rho_east','units','degree_east')
ncwriteatt(bryfilename,'lon_rho_east','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_rho_east','Dimensions',{'eta_rho',dim_eta_rho},'FillValue','disable');
ncwriteatt(bryfilename,'lat_rho_east','long_name','latitute of RHO-points, eastern boundary condition')
ncwriteatt(bryfilename,'lat_rho_east','units','degree_north')
ncwriteatt(bryfilename,'lat_rho_east','standard_name','latitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_rho_south','Dimensions',{'xi_rho',dim_xi_rho},'FillValue','disable');
ncwriteatt(bryfilename,'lon_rho_south','long_name','longitude of RHO-points, southern boundary condition')
ncwriteatt(bryfilename,'lon_rho_south','units','degree_east')
ncwriteatt(bryfilename,'lon_rho_south','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_rho_south','Dimensions',{'xi_rho',dim_xi_rho},'FillValue','disable');
ncwriteatt(bryfilename,'lat_rho_south','long_name','latitute of RHO-points, southern boundary condition')
ncwriteatt(bryfilename,'lat_rho_south','units','degree_north')
ncwriteatt(bryfilename,'lat_rho_south','standard_name','latitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_rho_north','Dimensions',{'xi_rho',dim_xi_rho},'FillValue','disable');
ncwriteatt(bryfilename,'lon_rho_north','long_name','longitude of RHO-points, northern boundary condition')
ncwriteatt(bryfilename,'lon_rho_north','units','degree_east')
ncwriteatt(bryfilename,'lon_rho_north','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_rho_north','Dimensions',{'xi_rho',dim_xi_rho},'FillValue','disable');
ncwriteatt(bryfilename,'lat_rho_north','long_name','latitute of RHO-points, northern boundary condition')
ncwriteatt(bryfilename,'lat_rho_north','units','degree_north')
ncwriteatt(bryfilename,'lat_rho_north','standard_name','latitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_u_west','Dimensions',{'eta_u',dim_eta_u},'FillValue','disable');
ncwriteatt(bryfilename,'lon_u_west','long_name','longitude of U-points, western boundary condition')
ncwriteatt(bryfilename,'lon_u_west','units','degree_east')
ncwriteatt(bryfilename,'lon_u_west','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_u_west','Dimensions',{'eta_u',dim_eta_u},'FillValue','disable');
ncwriteatt(bryfilename,'lat_u_west','long_name','latitute of U-points, western boundary condition')
ncwriteatt(bryfilename,'lat_u_west','units','degree_north')
ncwriteatt(bryfilename,'lat_u_west','standard_name','latitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_u_east','Dimensions',{'eta_u',dim_eta_u},'FillValue','disable');
ncwriteatt(bryfilename,'lon_u_east','long_name','longitude of U-points, eastern boundary condition')
ncwriteatt(bryfilename,'lon_u_east','units','degree_east')
ncwriteatt(bryfilename,'lon_u_east','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_u_east','Dimensions',{'eta_u',dim_eta_u},'FillValue','disable');
ncwriteatt(bryfilename,'lat_u_east','long_name','latitute of U-points, eastern boundary condition')
ncwriteatt(bryfilename,'lat_u_east','units','degree_north')
ncwriteatt(bryfilename,'lat_u_east','standard_name','latitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_u_south','Dimensions',{'xi_u',dim_xi_u},'FillValue','disable');
ncwriteatt(bryfilename,'lon_u_south','long_name','longitude of U-points, southern boundary condition')
ncwriteatt(bryfilename,'lon_u_south','units','degree_east')
ncwriteatt(bryfilename,'lon_u_south','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_u_south','Dimensions',{'xi_u',dim_xi_u},'FillValue','disable');
ncwriteatt(bryfilename,'lat_u_south','long_name','latitute of U-points, southern boundary condition')
ncwriteatt(bryfilename,'lat_u_south','units','degree_north')
ncwriteatt(bryfilename,'lat_u_south','standard_name','latitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_u_north','Dimensions',{'xi_u',dim_xi_u},'FillValue','disable');
ncwriteatt(bryfilename,'lon_u_north','long_name','longitude of U-points, northern boundary condition')
ncwriteatt(bryfilename,'lon_u_north','units','degree_east')
ncwriteatt(bryfilename,'lon_u_north','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_u_north','Dimensions',{'xi_u',dim_xi_u},'FillValue','disable');
ncwriteatt(bryfilename,'lat_u_north','long_name','latitute of U-points, northern boundary condition')
ncwriteatt(bryfilename,'lat_u_north','units','degree_north')
ncwriteatt(bryfilename,'lat_u_north','standard_name','latitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_v_west','Dimensions',{'eta_v',dim_eta_v},'FillValue','disable');
ncwriteatt(bryfilename,'lon_v_west','long_name','longitude of V-points, western boundary condition')
ncwriteatt(bryfilename,'lon_v_west','units','degree_east')
ncwriteatt(bryfilename,'lon_v_west','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_v_west','Dimensions',{'eta_v',dim_eta_v},'FillValue','disable');
ncwriteatt(bryfilename,'lat_v_west','long_name','latitute of V-points, western boundary condition')
ncwriteatt(bryfilename,'lat_v_west','units','degree_north')
ncwriteatt(bryfilename,'lat_v_west','standard_name','latitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_v_east','Dimensions',{'eta_v',dim_eta_v},'FillValue','disable');
ncwriteatt(bryfilename,'lon_v_east','long_name','longitude of V-points, eastern boundary condition')
ncwriteatt(bryfilename,'lon_v_east','units','degree_east')
ncwriteatt(bryfilename,'lon_v_east','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_v_east','Dimensions',{'eta_v',dim_eta_v},'FillValue','disable');
ncwriteatt(bryfilename,'lat_v_east','long_name','latitute of V-points, eastern boundary condition')
ncwriteatt(bryfilename,'lat_v_east','units','degree_north')
ncwriteatt(bryfilename,'lat_v_east','standard_name','latitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_v_south','Dimensions',{'xi_v',dim_xi_v},'FillValue','disable');
ncwriteatt(bryfilename,'lon_v_south','long_name','longitude of V-points, southern boundary condition')
ncwriteatt(bryfilename,'lon_v_south','units','degree_east')
ncwriteatt(bryfilename,'lon_v_south','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_v_south','Dimensions',{'xi_v',dim_xi_v},'FillValue','disable');
ncwriteatt(bryfilename,'lat_v_south','long_name','latitute of V-points, southern boundary condition')
ncwriteatt(bryfilename,'lat_v_south','units','degree_north')
ncwriteatt(bryfilename,'lat_v_south','standard_name','latitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lon_v_north','Dimensions',{'xi_v',dim_xi_v},'FillValue','disable');
ncwriteatt(bryfilename,'lon_v_north','long_name','longitude of V-points, northern boundary condition')
ncwriteatt(bryfilename,'lon_v_north','units','degree_east')
ncwriteatt(bryfilename,'lon_v_north','standard_name','longitude')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'lat_v_north','Dimensions',{'xi_v',dim_xi_v},'FillValue','disable');
ncwriteatt(bryfilename,'lat_v_north','long_name','latitute of V-points, northern boundary condition')
ncwriteatt(bryfilename,'lat_v_north','units','degree_north')
ncwriteatt(bryfilename,'lat_v_north','standard_name','latitude')
%--------------------------------------------------------------------------
nccreate(bryfilename,'bry_time','Dimensions',{'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'bry_time','long_name','time for ocean boundary variables')
ncwriteatt(bryfilename,'bry_time','units','days since 1998-01-01 00:00:00')
ncwriteatt(bryfilename,'bry_time','calendar','365.0 days in every year')
%--------------------------------------------------------------------------
nccreate(bryfilename,'ocean_time','Dimensions',{'ocean_time',dim_ocean_time},'FillValue','disable');
ncwriteatt(bryfilename,'ocean_time','long_name','time for ocean boundary variables')
ncwriteatt(bryfilename,'ocean_time','units','days since 1998-01-01 00:00:00')
ncwriteatt(bryfilename,'ocean_time','calendar','365.0 days in every year')
%--------------------------------------------------------------------------
nccreate(bryfilename,'zeta_time','Dimensions',{'zeta_time',dim_zeta_time},'FillValue','disable');
ncwriteatt(bryfilename,'zeta_time','long_name','time for ocean boundary variables')
ncwriteatt(bryfilename,'zeta_time','units','days since 1998-01-01 00:00:00')
ncwriteatt(bryfilename,'zeta_time','calendar','365.0 days in every year')
%--------------------------------------------------------------------------
nccreate(bryfilename,'v2d_time','Dimensions',{'v2d_time',dim_v2d_time},'FillValue','disable');
ncwriteatt(bryfilename,'v2d_time','long_name','time for ocean boundary variables')
ncwriteatt(bryfilename,'v2d_time','units','days since 1998-01-01 00:00:00')
ncwriteatt(bryfilename,'v2d_time','calendar','365.0 days in every year')
%--------------------------------------------------------------------------
nccreate(bryfilename,'temp_time','Dimensions',{'temp_time',dim_temp_time},'FillValue','disable');
ncwriteatt(bryfilename,'temp_time','long_name','time for ocean boundary variables')
ncwriteatt(bryfilename,'temp_time','units','days since 1998-01-01 00:00:00')
ncwriteatt(bryfilename,'temp_time','calendar','365.0 days in every year')
%--------------------------------------------------------------------------
nccreate(bryfilename,'salt_time','Dimensions',{'salt_time',dim_salt_time},'FillValue','disable');
ncwriteatt(bryfilename,'salt_time','long_name','time for ocean boundary variables')
ncwriteatt(bryfilename,'salt_time','units','days since 1998-01-01 00:00:00')
ncwriteatt(bryfilename,'salt_time','calendar','365.0 days in every year')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'zeta_west','Dimensions',{'eta_rho',dim_eta_rho,'zeta_time',dim_zeta_time},'FillValue','disable');
ncwriteatt(bryfilename,'zeta_west','long_name','free-surface, western boundary condition')
ncwriteatt(bryfilename,'zeta_west','units','meter')
ncwriteatt(bryfilename,'zeta_west','time','zeta_time')
ncwriteatt(bryfilename,'zeta_west','coordinates','lon_rho_west lat_rho_west zeta_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'zeta_east','Dimensions',{'eta_rho',dim_eta_rho,'zeta_time',dim_zeta_time},'FillValue','disable');
ncwriteatt(bryfilename,'zeta_east','long_name','free-surface, eastern boundary condition')
ncwriteatt(bryfilename,'zeta_east','units','meter')
ncwriteatt(bryfilename,'zeta_east','time','zeta_time')
ncwriteatt(bryfilename,'zeta_east','coordinates','lon_rho_east lat_rho_east zeta_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'zeta_south','Dimensions',{'xi_rho',dim_xi_rho,'zeta_time',dim_zeta_time},'FillValue','disable');
ncwriteatt(bryfilename,'zeta_south','long_name','free-surface, southern boundary condition')
ncwriteatt(bryfilename,'zeta_south','units','meter')
ncwriteatt(bryfilename,'zeta_south','time','zeta_time')
ncwriteatt(bryfilename,'zeta_south','coordinates','lon_rho_south lat_rho_south zeta_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'zeta_north','Dimensions',{'xi_rho',dim_xi_rho,'zeta_time',dim_zeta_time},'FillValue','disable');
ncwriteatt(bryfilename,'zeta_north','long_name','free-surface, northern boundary condition')
ncwriteatt(bryfilename,'zeta_north','units','meter')
ncwriteatt(bryfilename,'zeta_north','time','zeta_time')
ncwriteatt(bryfilename,'zeta_north','coordinates','lon_rho_north lat_rho_north zeta_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'ubar_west','Dimensions',{'eta_u_rho',dim_eta_u,'v2d_time',dim_v2d_time},'FillValue','disable');
ncwriteatt(bryfilename,'ubar_west','long_name','vertically integrated u-momentum component, western boundary condition')
ncwriteatt(bryfilename,'ubar_west','units','meter second-1')
ncwriteatt(bryfilename,'ubar_west','time','v2d_time')
ncwriteatt(bryfilename,'ubar_west','coordinates','lon_u_west lat_u_west v2d_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'ubar_east','Dimensions',{'eta_u_rho',dim_eta_u,'v2d_time',dim_v2d_time},'FillValue','disable');
ncwriteatt(bryfilename,'ubar_east','long_name','vertically integrated u-momentum component, eastern boundary condition')
ncwriteatt(bryfilename,'ubar_east','units','meter second-1')
ncwriteatt(bryfilename,'ubar_east','time','v2d_time')
ncwriteatt(bryfilename,'ubar_east','coordinates','lon_u_east lat_u_east v2d_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'ubar_south','Dimensions',{'xi_u_rho',dim_xi_u,'v2d_time',dim_v2d_time},'FillValue','disable');
ncwriteatt(bryfilename,'ubar_south','long_name','vertically integrated u-momentum component, southern boundary condition')
ncwriteatt(bryfilename,'ubar_south','units','meter second-1')
ncwriteatt(bryfilename,'ubar_south','time','v2d_time')
ncwriteatt(bryfilename,'ubar_south','coordinates','lon_u_south lat_u_south v2d_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'ubar_north','Dimensions',{'xi_u_rho',dim_xi_u,'v2d_time',dim_v2d_time},'FillValue','disable');
ncwriteatt(bryfilename,'ubar_north','long_name','vertically integrated u-momentum component, northern boundary condition')
ncwriteatt(bryfilename,'ubar_north','units','meter second-1')
ncwriteatt(bryfilename,'ubar_north','time','v2d_time')
ncwriteatt(bryfilename,'ubar_north','coordinates','lon_u_north lat_u_north v2d_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'vbar_west','Dimensions',{'eta_v_rho',dim_eta_v,'v2d_time',dim_v2d_time},'FillValue','disable');
ncwriteatt(bryfilename,'vbar_west','long_name','vertically integrated v-momentum component, western boundary condition')
ncwriteatt(bryfilename,'vbar_west','units','meter second-1')
ncwriteatt(bryfilename,'vbar_west','time','v2d_time')
ncwriteatt(bryfilename,'vbar_west','coordinates','lon_v_west lat_v_west v2d_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'vbar_east','Dimensions',{'eta_v_rho',dim_eta_v,'v2d_time',dim_v2d_time},'FillValue','disable');
ncwriteatt(bryfilename,'vbar_east','long_name','vertically integrated v-momentum component, eastern boundary condition')
ncwriteatt(bryfilename,'vbar_east','units','meter second-1')
ncwriteatt(bryfilename,'vbar_east','time','v2d_time')
ncwriteatt(bryfilename,'vbar_east','coordinates','lon_v_east lat_v_east v2d_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'vbar_south','Dimensions',{'xi_v_rho',dim_xi_v,'v2d_time',dim_v2d_time},'FillValue','disable');
ncwriteatt(bryfilename,'vbar_south','long_name','vertically integrated v-momentum component, southern boundary condition')
ncwriteatt(bryfilename,'vbar_south','units','meter second-1')
ncwriteatt(bryfilename,'vbar_south','time','v2d_time')
ncwriteatt(bryfilename,'vbar_south','coordinates','lon_v_south lat_v_south v2d_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'vbar_north','Dimensions',{'xi_v_rho',dim_xi_v,'v2d_time',dim_v2d_time},'FillValue','disable');
ncwriteatt(bryfilename,'vbar_north','long_name','vertically integrated v-momentum component, northern boundary condition')
ncwriteatt(bryfilename,'vbar_north','units','meter second-1')
ncwriteatt(bryfilename,'vbar_north','time','v2d_time')
ncwriteatt(bryfilename,'vbar_north','coordinates','lon_v_north lat_v_north v2d_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'temp_west','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'temp_time',dim_temp_time},'FillValue','disable');
ncwriteatt(bryfilename,'temp_west','long_name','potential temperature, western boundary condition')
ncwriteatt(bryfilename,'temp_west','units','Celsius')
ncwriteatt(bryfilename,'temp_west','time','temp_time')
ncwriteatt(bryfilename,'temp_west','coordinates','lon_rho lat_rho s_rho temp_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'temp_east','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'temp_time',dim_temp_time},'FillValue','disable');
ncwriteatt(bryfilename,'temp_east','long_name','potential temperature, eastern boundary condition')
ncwriteatt(bryfilename,'temp_east','units','Celsius')
ncwriteatt(bryfilename,'temp_east','time','temp_time')
ncwriteatt(bryfilename,'temp_east','coordinates','lon_rho_east lat_rho_east s_rho temp_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'temp_south','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'temp_time',dim_temp_time},'FillValue','disable');
ncwriteatt(bryfilename,'temp_south','long_name','potential temperature, southern boundary condition')
ncwriteatt(bryfilename,'temp_south','units','Celsius')
ncwriteatt(bryfilename,'temp_south','time','temp_time')
ncwriteatt(bryfilename,'temp_south','coordinates','lon_rho_east lat_rho_east s_rho temp_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'temp_north','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'temp_time',dim_temp_time},'FillValue','disable');
ncwriteatt(bryfilename,'temp_north','long_name','potential temperature, northern boundary condition')
ncwriteatt(bryfilename,'temp_north','units','Celsius')
ncwriteatt(bryfilename,'temp_north','time','temp_time')
ncwriteatt(bryfilename,'temp_north','coordinates','lon_rho_east lat_rho_east s_rho temp_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'salt_west','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'salt_time',dim_salt_time},'FillValue','disable');
ncwriteatt(bryfilename,'salt_west','long_name','salinity, western boundary condition')
ncwriteatt(bryfilename,'salt_west','time','salt_time')
ncwriteatt(bryfilename,'salt_west','coordinates','lon_rho_west lat_rho_west s_rho salt_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'salt_east','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'salt_time',dim_salt_time},'FillValue','disable');
ncwriteatt(bryfilename,'salt_east','long_name','salinity, eastern boundary condition')
ncwriteatt(bryfilename,'salt_east','time','salt_time')
ncwriteatt(bryfilename,'salt_east','coordinates','lon_rho_east lat_rho_east s_rho salt_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'salt_south','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'salt_time',dim_salt_time},'FillValue','disable');
ncwriteatt(bryfilename,'salt_south','long_name','salinity, southern boundary condition')
ncwriteatt(bryfilename,'salt_south','time','salt_time')
ncwriteatt(bryfilename,'salt_south','coordinates','lon_rho_south lat_rho_south s_rho salt_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'salt_north','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'salt_time',dim_salt_time},'FillValue','disable');
ncwriteatt(bryfilename,'salt_north','long_name','salinity, northern boundary condition')
ncwriteatt(bryfilename,'salt_north','time','salt_time')
ncwriteatt(bryfilename,'salt_north','coordinates','lon_rho_north lat_rho_north s_rho salt_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'aice_west','Dimensions',{'eta_rho',dim_eta_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'aice_west','long_name','ice concentration 0-1, western boundary condition')
ncwriteatt(bryfilename,'aice_west','time','bry_time')
ncwriteatt(bryfilename,'aice_west','coordinates','lon_rho_west lat_rho_west bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'aice_east','Dimensions',{'eta_rho',dim_eta_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'aice_east','long_name','ice concentration 0-1, eastern boundary condition')
ncwriteatt(bryfilename,'aice_east','time','bry_time')
ncwriteatt(bryfilename,'aice_east','coordinates','lon_rho_east lat_rho_east bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'aice_south','Dimensions',{'xi_rho',dim_xi_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'aice_south','long_name','ice concentration 0-1, southern boundary condition')
ncwriteatt(bryfilename,'aice_south','time','bry_time')
ncwriteatt(bryfilename,'aice_south','coordinates','lon_rho_south lat_rho_south bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'aice_north','Dimensions',{'xi_rho',dim_xi_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'aice_north','long_name','ice concentration 0-1, northern boundary condition')
ncwriteatt(bryfilename,'aice_north','time','bry_time')
ncwriteatt(bryfilename,'aice_north','coordinates','lon_rho_north lat_rho_north bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'dye_west_01','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_west_01','long_name','CDW tracer, western boundary condition')
ncwriteatt(bryfilename,'dye_west_01','time','bry_time')
ncwriteatt(bryfilename,'dye_west_01','coordinates','bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'dye_east_01','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_east_01','long_name','CDW tracer, eastern boundary condition')
ncwriteatt(bryfilename,'dye_east_01','time','bry_time')
ncwriteatt(bryfilename,'dye_east_01','coordinates','bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'dye_south_01','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_south_01','long_name','CDW tracer, southern boundary condition')
ncwriteatt(bryfilename,'dye_south_01','time','bry_time')
ncwriteatt(bryfilename,'dye_south_01','coordinates','bry_time')
%--------------------------------------------------------------------------
nccreate(bryfilename,'dye_north_01','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_north_01','long_name','CDW tracer, northern boundary condition')
ncwriteatt(bryfilename,'dye_north_01','time','bry_time')
ncwriteatt(bryfilename,'dye_north_01','coordinates','bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'dye_west_02','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_west_02','long_name','Sea ice melt tracer, western boundary condition')
ncwriteatt(bryfilename,'dye_west_02','time','bry_time')
ncwriteatt(bryfilename,'dye_west_02','coordinates','lon_rho_west lat_rho_west s_rho bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'dye_east_02','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_east_02','long_name','Sea ice melt tracer, eastern boundary condition')
ncwriteatt(bryfilename,'dye_east_02','time','bry_time')
ncwriteatt(bryfilename,'dye_east_02','coordinates','lon_rho_east lat_rho_east s_rho bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'dye_south_02','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_south_02','long_name','Sea ice melt tracer, southern boundary condition')
ncwriteatt(bryfilename,'dye_south_02','time','bry_time')
ncwriteatt(bryfilename,'dye_south_02','coordinates','lon_rho_south lat_rho_south s_rho bry_time')
%--------------------------------------------------------------------------
nccreate(bryfilename,'dye_north_02','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_north_02','long_name','Sea ice melt tracer, northern boundary condition')
ncwriteatt(bryfilename,'dye_north_02','time','bry_time')
ncwriteatt(bryfilename,'dye_north_02','coordinates','lon_rho_north lat_rho_north s_rho bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'dye_west_03','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_west_03','long_name','Ice shelf melt tracer, western boundary condition')
ncwriteatt(bryfilename,'dye_west_03','time','bry_time')
ncwriteatt(bryfilename,'dye_west_03','coordinates','lon_rho_west lat_rho_west bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'dye_east_03','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_east_03','long_name','Ice shelf melt tracer, eastern boundary condition')
ncwriteatt(bryfilename,'dye_east_03','time','bry_time')
ncwriteatt(bryfilename,'dye_east_03','coordinates','lon_rho_east lat_rho_east bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'dye_south_03','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_south_03','long_name','Ice shelf melt tracer, southern boundary condition')
ncwriteatt(bryfilename,'dye_south_03','time','bry_time')
ncwriteatt(bryfilename,'dye_south_03','coordinates','lon_rho_south lat_rho_south bry_time')
%--------------------------------------------------------------------------
nccreate(bryfilename,'dye_north_03','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_north_03','long_name','Ice shelf melt tracer, northern boundary condition')
ncwriteatt(bryfilename,'dye_north_03','time','bry_time')
ncwriteatt(bryfilename,'dye_north_03','coordinates','lon_rho_north lat_rho_north bry_time')
if idye04
%--------------------------------------------------------------------------
nccreate(bryfilename,'dye_west_04','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_west_04','long_name','dye_04 tracer, western boundary condition')
ncwriteatt(bryfilename,'dye_west_04','time','bry_time')
ncwriteatt(bryfilename,'dye_west_04','coordinates','lon_rho_west lat_rho_west bry_time')
% %--------------------------------------------------------------------------
nccreate(bryfilename,'dye_east_04','Dimensions',{'eta_rho',dim_eta_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_east_04','long_name','dye_04 tracer, eastern boundary condition')
ncwriteatt(bryfilename,'dye_east_04','time','bry_time')
ncwriteatt(bryfilename,'dye_east_04','coordinates','lon_rho_east lat_rho_east bry_time')
% %-------------------------------------------------------------------------
nccreate(bryfilename,'dye_south_04','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_south_04','long_name','dye_04 tracer, southern boundary condition')
ncwriteatt(bryfilename,'dye_south_04','time','bry_time')
ncwriteatt(bryfilename,'dye_south_04','coordinates','lon_rho_south lat_rho_south bry_time')
%--------------------------------------------------------------------------
nccreate(bryfilename,'dye_north_04','Dimensions',{'xi_rho',dim_xi_rho,'s_rho',dim_s_rho,'bry_time',dim_bry_time},'FillValue','disable');
ncwriteatt(bryfilename,'dye_north_04','long_name','dye_04 tracer, northern boundary condition')
ncwriteatt(bryfilename,'dye_north_04','time','bry_time')
ncwriteatt(bryfilename,'dye_north_04','coordinates','lon_rho_north lat_rho_north bry_time')
%--------------------------------------------------------------------------
end

disp('      => Loading Boundary data ...');
bry_time=t_temp_bry';
ocean_time=bry_time;
temp_time=bry_time;
salt_time=bry_time;
if itide
   zeta_time=time_tide;
   v2d_time=time_tide;
else
   zeta_time=bry_time;
   v2d_time=bry_time;
end
% ---------------- write variables -----------------
disp('      => Filling Variables...')
ncwrite(bryfilename,'spherical',spherical);
ncwrite(bryfilename,'Vtransform',Vtransform);
ncwrite(bryfilename,'Vstretching',Vstretching);
ncwrite(bryfilename,'theta_s',theta_s);
ncwrite(bryfilename,'theta_b',theta_b);
ncwrite(bryfilename,'Tcline',Tcline);
ncwrite(bryfilename,'hc',hc);
ncwrite(bryfilename,'s_rho',s_rho);
ncwrite(bryfilename,'s_w',s_w);
ncwrite(bryfilename,'Cs_r',Cs_r);
ncwrite(bryfilename,'Cs_w',Cs_w);
ncwrite(bryfilename,'lon_rho_west',lon_rho_west);
ncwrite(bryfilename,'lat_rho_west',lat_rho_west);
ncwrite(bryfilename,'lon_rho_east',lon_rho_east);
ncwrite(bryfilename,'lat_rho_east',lat_rho_east);
ncwrite(bryfilename,'lon_rho_south',lon_rho_south);
ncwrite(bryfilename,'lat_rho_south',lat_rho_south);
ncwrite(bryfilename,'lon_rho_north',lon_rho_north);
ncwrite(bryfilename,'lat_rho_north',lat_rho_north);
ncwrite(bryfilename,'lon_u_west',lon_u_west);
ncwrite(bryfilename,'lat_u_west',lat_u_west);
ncwrite(bryfilename,'lon_u_east',lon_u_east);
ncwrite(bryfilename,'lat_u_east',lat_u_east);
ncwrite(bryfilename,'lon_u_south',lon_u_south);
ncwrite(bryfilename,'lat_u_south',lat_u_south);
ncwrite(bryfilename,'lon_u_north',lon_u_north);
ncwrite(bryfilename,'lat_u_north',lat_u_north);
ncwrite(bryfilename,'lon_v_west',lon_v_west);
ncwrite(bryfilename,'lat_v_west',lat_v_west);
ncwrite(bryfilename,'lon_v_east',lon_v_east);
ncwrite(bryfilename,'lat_v_east',lat_v_east);
ncwrite(bryfilename,'lon_v_south',lon_v_south);
ncwrite(bryfilename,'lat_v_south',lat_v_south);
ncwrite(bryfilename,'lon_v_north',lon_v_north);
ncwrite(bryfilename,'lat_v_north',lat_v_north);
ncwrite(bryfilename,'bry_time',bry_time);
ncwrite(bryfilename,'ocean_time',ocean_time);
ncwrite(bryfilename,'zeta_time',zeta_time);
ncwrite(bryfilename,'v2d_time',v2d_time);
ncwrite(bryfilename,'temp_time',temp_time);
ncwrite(bryfilename,'salt_time',salt_time);
if itide
    ncwrite(bryfilename,'zeta_west',zeta_west_tide);
    ncwrite(bryfilename,'zeta_east',zeta_east_tide);
    ncwrite(bryfilename,'zeta_south',zeta_south_tide);
    ncwrite(bryfilename,'zeta_north',zeta_north_tide);
    ncwrite(bryfilename,'ubar_west',ubar_west_tide);
    ncwrite(bryfilename,'ubar_east',ubar_east_tide);
    ncwrite(bryfilename,'ubar_south',ubar_south_tide);
    ncwrite(bryfilename,'ubar_north',ubar_north_tide);
    ncwrite(bryfilename,'vbar_west',vbar_west_tide);
    ncwrite(bryfilename,'vbar_east',vbar_east_tide);
    ncwrite(bryfilename,'vbar_south',vbar_south_tide);
    ncwrite(bryfilename,'vbar_north',vbar_north_tide);
else
    ncwrite(bryfilename,'zeta_west',zeta_west_bry);
    ncwrite(bryfilename,'zeta_east',zeta_east_bry);
    ncwrite(bryfilename,'zeta_south',zeta_south_bry);
    ncwrite(bryfilename,'zeta_north',zeta_north_bry);
    ncwrite(bryfilename,'ubar_west',ubar_west_bry);
    ncwrite(bryfilename,'ubar_east',ubar_east_bry);
    ncwrite(bryfilename,'ubar_south',ubar_south_bry);
    ncwrite(bryfilename,'ubar_north',ubar_north_bry);
    ncwrite(bryfilename,'vbar_west',vbar_west_bry);
    ncwrite(bryfilename,'vbar_east',vbar_east_bry);
    ncwrite(bryfilename,'vbar_south',vbar_south_bry);
    ncwrite(bryfilename,'vbar_north',vbar_north_bry);
end
ncwrite(bryfilename,'temp_west',temp_west_bry);
ncwrite(bryfilename,'temp_east',temp_east_bry);
ncwrite(bryfilename,'temp_south',temp_south_bry);
ncwrite(bryfilename,'temp_north',temp_north_bry);
ncwrite(bryfilename,'salt_west',salt_west_bry);
ncwrite(bryfilename,'salt_east',salt_east_bry);
ncwrite(bryfilename,'salt_south',salt_south_bry);
ncwrite(bryfilename,'salt_north',salt_north_bry);
ncwrite(bryfilename,'aice_west',aice_west_bry);
ncwrite(bryfilename,'aice_east',aice_east_bry);
ncwrite(bryfilename,'aice_south',aice_south_bry);
ncwrite(bryfilename,'aice_north',aice_north_bry);
ncwrite(bryfilename,'dye_west_01',dye_east_01_bry);
ncwrite(bryfilename,'dye_east_01',dye_east_01_bry);
ncwrite(bryfilename,'dye_south_01',dye_south_01_bry);
ncwrite(bryfilename,'dye_north_01',dye_north_01_bry);
ncwrite(bryfilename,'dye_west_02',dye_east_02_bry);
ncwrite(bryfilename,'dye_east_02',dye_east_02_bry);
ncwrite(bryfilename,'dye_south_02',dye_south_02_bry);
ncwrite(bryfilename,'dye_north_02',dye_north_03_bry);
ncwrite(bryfilename,'dye_west_03',dye_east_03_bry);
ncwrite(bryfilename,'dye_east_03',dye_east_03_bry);
ncwrite(bryfilename,'dye_south_03',dye_south_03_bry);
ncwrite(bryfilename,'dye_north_03',dye_north_03_bry);
if idye04
ncwrite(bryfilename,'dye_west_04',dye_east_02_bry);
ncwrite(bryfilename,'dye_east_04',dye_east_02_bry);
ncwrite(bryfilename,'dye_south_04',dye_south_02_bry);
ncwrite(bryfilename,'dye_north_04',dye_north_02_bry);
end

%-------------------- Write Global Attributes -----------------
disp('      => Creating Global Attributes...')
ncwriteatt(bryfilename,'/','History','BOUNDARY file for RAS model');
ncwriteatt(bryfilename,'/','Create_time',datestr(now));
ncwriteatt(bryfilename,'/','Type','Glosea5 data');
ncwriteatt(bryfilename,'/','Time','days (since 1998-01-01 00:00:00)');
ncwriteatt(bryfilename,'/','Out_file',bryfilename);
ncwriteatt(bryfilename,'/','Grd_file',grdfilename);

disp('  Done !');

%%  ϰ汾NCļʽNETCDF3_CLASSICļСΪ2G
% -------------------------------------------------------------------------
% ------------------------- Create netcdf file ----------------------------
% -------------------------------------------------------------------------
% --- creat file ---
disp('  Creating NC file...')
ncid = netcdf.create(bryfilename,'NC_CLOBBER');
% --- define dimensions ---
disp('    => Defining Dimensions...')
% %
xi_rho_ID = netcdf.defDim(ncid,'xi_rho',Lp);
xi_u_ID = netcdf.defDim(ncid,'xi_u',L);
xi_v_ID = netcdf.defDim(ncid,'xi_v',Lp);
eta_rho_ID = netcdf.defDim(ncid,'eta_rho',Mp);
eta_u_ID = netcdf.defDim(ncid,'eta_u',Mp);
eta_v_ID = netcdf.defDim(ncid,'eta_v',M); 
s_rho_ID = netcdf.defDim(ncid,'s_rho',N);
s_w_ID = netcdf.defDim(ncid,'s_w',Np);
tracer_ID = netcdf.defDim(ncid,'tracer',5);
bry_time1_ID = netcdf.defDim(ncid,'bry_time',365);
ocean_time1_ID = netcdf.defDim(ncid,'ocean_time',365);
one_ID = netcdf.defDim(ncid,'one',1);
% 
% --- define Variables and attributes ---
disp('    => Defining Variables and Attributes...')
% %--------------------------------------------------------------------------
spherical_ID = netcdf.defVar(ncid,'spherical','char',one_ID);
netcdf.putAtt(ncid,spherical_ID,'long_name','grid type logical switch')
netcdf.putAtt(ncid,spherical_ID,'flag_values',[0  1])
netcdf.putAtt(ncid,spherical_ID,'flag_meanings','Cartesian spherical')
% %--------------------------------------------------------------------------
Vtransform_ID = netcdf.defVar(ncid,'Vtransform','int',one_ID);
netcdf.putAtt(ncid,Vtransform_ID,'long_name','vertical terrain-following transformation equation')
% %--------------------------------------------------------------------------
Vstretching_ID = netcdf.defVar(ncid,'Vstretching','int',one_ID);
netcdf.putAtt(ncid,Vstretching_ID,'long_name','vertical terrain-following stretching function')
% %--------------------------------------------------------------------------
theta_s_ID = netcdf.defVar(ncid,'theta_s','double',one_ID);
netcdf.putAtt(ncid,theta_s_ID,'long_name','S-coordinate surface control parameter')
% %--------------------------------------------------------------------------
theta_b_ID = netcdf.defVar(ncid,'theta_b','double',one_ID);
netcdf.putAtt(ncid,theta_b_ID,'long_name','S-coordinate bottom control parameter')
% %--------------------------------------------------------------------------
Tcline_ID = netcdf.defVar(ncid,'Tcline','double',one_ID);
netcdf.putAtt(ncid,Tcline_ID,'long_name','S-coordinate surface/bottom layer width')
netcdf.putAtt(ncid,Tcline_ID,'units','meter')
% %--------------------------------------------------------------------------
hc_ID = netcdf.defVar(ncid,'hc','double',one_ID);
netcdf.putAtt(ncid,hc_ID,'long_name','S-coordinate parameter, critical depth')
netcdf.putAtt(ncid,hc_ID,'units','meter')
% %--------------------------------------------------------------------------
s_rho1_ID = netcdf.defVar(ncid,'s_rho','double',s_rho_ID);
netcdf.putAtt(ncid,s_rho1_ID,'long_name','S-coordinate at RHO-points')
netcdf.putAtt(ncid,s_rho1_ID,'valid_min',-1)
netcdf.putAtt(ncid,s_rho1_ID,'valid_max',0)
netcdf.putAtt(ncid,s_rho1_ID,'positive','up')
netcdf.putAtt(ncid,s_rho1_ID,'standard_name','ocean_s_coordinate_g1')
netcdf.putAtt(ncid,s_rho1_ID,'formula_terms','s: s_rho C: Cs_r eta: zeta depth: h depth_c: hc')
% %--------------------------------------------------------------------------
s_w1_ID = netcdf.defVar(ncid,'s_w','double',s_w_ID);
netcdf.putAtt(ncid,s_w1_ID,'long_name','S-coordinate at W-points')
netcdf.putAtt(ncid,s_w1_ID,'valid_min',-1)
netcdf.putAtt(ncid,s_w1_ID,'valid_max',0)
netcdf.putAtt(ncid,s_w1_ID,'positive','up')
netcdf.putAtt(ncid,s_w1_ID,'standard_name','ocean_s_coordinate_g1')
netcdf.putAtt(ncid,s_w1_ID,'formula_terms','s: s_w C: Cs_w eta: zeta depth: h depth_c: hc')
% %--------------------------------------------------------------------------
Cs_r_ID = netcdf.defVar(ncid,'Cs_r','double',s_rho_ID);
netcdf.putAtt(ncid,Cs_r_ID,'long_name','S-coordinate stretching function at RHO-points')
netcdf.putAtt(ncid,Cs_r_ID,'valid_min',-1)
netcdf.putAtt(ncid,Cs_r_ID,'valid_max',0)
% %--------------------------------------------------------------------------
Cs_w_ID = netcdf.defVar(ncid,'Cs_w','double',s_w_ID);
netcdf.putAtt(ncid,Cs_w_ID,'long_name','S-coordinate stretching function at W-points')
netcdf.putAtt(ncid,Cs_w_ID,'valid_min',-1)
netcdf.putAtt(ncid,Cs_w_ID,'valid_max',0)
% %--------------------------------------------------------------------------
lon_rho_west_ID = netcdf.defVar(ncid,'lon_rho_west','double',[eta_rho_ID]);
netcdf.putAtt(ncid,lon_rho_west_ID,'long_name','longitude of RHO-points, western boundary condition')
netcdf.putAtt(ncid,lon_rho_west_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_rho_west_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_rho_west_ID = netcdf.defVar(ncid,'lat_rho_west','double',[eta_rho_ID]);
netcdf.putAtt(ncid,lat_rho_west_ID,'long_name','latitute of RHO-points, western boundary condition')
netcdf.putAtt(ncid,lat_rho_west_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_rho_west_ID,'standard_name','latitude')
% %--------------------------------------------------------------------------
lon_rho_east_ID = netcdf.defVar(ncid,'lon_rho_east','double',[eta_rho_ID]);
netcdf.putAtt(ncid,lon_rho_east_ID,'long_name','longitude of RHO-points, eastern boundary condition')
netcdf.putAtt(ncid,lon_rho_east_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_rho_east_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_rho_east_ID = netcdf.defVar(ncid,'lat_rho_east','double',[eta_rho_ID]);
netcdf.putAtt(ncid,lat_rho_east_ID,'long_name','latitute of RHO-points, eastern boundary condition')
netcdf.putAtt(ncid,lat_rho_east_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_rho_east_ID,'standard_name','latitude')
% %--------------------------------------------------------------------------
lon_rho_south_ID = netcdf.defVar(ncid,'lon_rho_south','double',[xi_rho_ID]);
netcdf.putAtt(ncid,lon_rho_south_ID,'long_name','longitude of RHO-points, southern boundary condition')
netcdf.putAtt(ncid,lon_rho_south_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_rho_south_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_rho_south_ID = netcdf.defVar(ncid,'lat_rho_south','double',[xi_rho_ID]);
netcdf.putAtt(ncid,lat_rho_south_ID,'long_name','latitute of RHO-points, southern boundary condition')
netcdf.putAtt(ncid,lat_rho_south_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_rho_south_ID,'standard_name','latitude')
% %--------------------------------------------------------------------------
lon_rho_north_ID = netcdf.defVar(ncid,'lon_rho_north','double',[xi_rho_ID]);
netcdf.putAtt(ncid,lon_rho_north_ID,'long_name','longitude of RHO-points, northern boundary condition')
netcdf.putAtt(ncid,lon_rho_north_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_rho_north_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_rho_north_ID = netcdf.defVar(ncid,'lat_rho_north','double',[xi_rho_ID]);
netcdf.putAtt(ncid,lat_rho_north_ID,'long_name','latitute of RHO-points, northern boundary condition')
netcdf.putAtt(ncid,lat_rho_north_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_rho_north_ID,'standard_name','latitude')
% %--------------------------------------------------------------------------
lon_u_west_ID = netcdf.defVar(ncid,'lon_u_west','double',[eta_u_ID]);
netcdf.putAtt(ncid,lon_u_west_ID,'long_name','longitude of U-points, western boundary condition')
netcdf.putAtt(ncid,lon_u_west_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_u_west_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_u_west_ID = netcdf.defVar(ncid,'lat_u_west','double',[eta_u_ID]);
netcdf.putAtt(ncid,lat_u_west_ID,'long_name','latitute of U-points, western boundary condition')
netcdf.putAtt(ncid,lat_u_west_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_u_west_ID,'standard_name','latitude')
% %--------------------------------------------------------------------------
lon_u_east_ID = netcdf.defVar(ncid,'lon_u_east','double',[eta_u_ID]);
netcdf.putAtt(ncid,lon_u_east_ID,'long_name','longitude of U-points, eastern boundary condition')
netcdf.putAtt(ncid,lon_u_east_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_u_east_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_u_east_ID = netcdf.defVar(ncid,'lat_u_east','double',[eta_u_ID]);
netcdf.putAtt(ncid,lat_u_east_ID,'long_name','latitute of U-points, eastern boundary condition')
netcdf.putAtt(ncid,lat_u_east_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_u_east_ID,'standard_name','latitude')
% %--------------------------------------------------------------------------
lon_u_south_ID = netcdf.defVar(ncid,'lon_u_south','double',[xi_u_ID]);
netcdf.putAtt(ncid,lon_u_south_ID,'long_name','longitude of U-points, southern boundary condition')
netcdf.putAtt(ncid,lon_u_south_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_u_south_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_u_south_ID = netcdf.defVar(ncid,'lat_u_south','double',[xi_u_ID]);
netcdf.putAtt(ncid,lat_u_south_ID,'long_name','latitute of U-points, southern boundary condition')
netcdf.putAtt(ncid,lat_u_south_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_u_south_ID,'standard_name','latitude')
% %--------------------------------------------------------------------------
lon_u_north_ID = netcdf.defVar(ncid,'lon_u_north','double',[xi_u_ID]);
netcdf.putAtt(ncid,lon_u_north_ID,'long_name','longitude of U-points, northern boundary condition')
netcdf.putAtt(ncid,lon_u_north_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_u_north_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_u_north_ID = netcdf.defVar(ncid,'lat_u_north','double',[xi_u_ID]);
netcdf.putAtt(ncid,lat_u_north_ID,'long_name','latitute of U-points, northern boundary condition')
netcdf.putAtt(ncid,lat_u_north_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_u_north_ID,'standard_name','latitude')
% %--------------------------------------------------------------------------
lon_v_west_ID = netcdf.defVar(ncid,'lon_v_west','double',[eta_v_ID]);
netcdf.putAtt(ncid,lon_v_west_ID,'long_name','longitude of V-points, western boundary condition')
netcdf.putAtt(ncid,lon_v_west_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_v_west_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_v_west_ID = netcdf.defVar(ncid,'lat_v_west','double',[eta_v_ID]);
netcdf.putAtt(ncid,lat_v_west_ID,'long_name','latitute of V-points, western boundary condition')
netcdf.putAtt(ncid,lat_v_west_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_v_west_ID,'standard_name','latitude')
% %--------------------------------------------------------------------------
lon_v_east_ID = netcdf.defVar(ncid,'lon_v_east','double',[eta_v_ID]);
netcdf.putAtt(ncid,lon_v_east_ID,'long_name','longitude of V-points, eastern boundary condition')
netcdf.putAtt(ncid,lon_v_east_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_v_east_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_v_east_ID = netcdf.defVar(ncid,'lat_v_east','double',[eta_v_ID]);
netcdf.putAtt(ncid,lat_v_east_ID,'long_name','latitute of V-points, eastern boundary condition')
netcdf.putAtt(ncid,lat_v_east_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_v_east_ID,'standard_name','latitude')
% %--------------------------------------------------------------------------
lon_v_south_ID = netcdf.defVar(ncid,'lon_v_south','double',[xi_v_ID]);
netcdf.putAtt(ncid,lon_v_south_ID,'long_name','longitude of V-points, southern boundary condition')
netcdf.putAtt(ncid,lon_v_south_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_v_south_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_v_south_ID = netcdf.defVar(ncid,'lat_v_south','double',[xi_v_ID]);
netcdf.putAtt(ncid,lat_v_south_ID,'long_name','latitute of V-points, southern boundary condition')
netcdf.putAtt(ncid,lat_v_south_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_v_south_ID,'standard_name','latitude')
% %--------------------------------------------------------------------------
lon_v_north_ID = netcdf.defVar(ncid,'lon_v_north','double',[xi_v_ID]);
netcdf.putAtt(ncid,lon_v_north_ID,'long_name','longitude of V-points, northern boundary condition')
netcdf.putAtt(ncid,lon_v_north_ID,'units','degree_east')
netcdf.putAtt(ncid,lon_v_north_ID,'standard_name','longitude')
% %--------------------------------------------------------------------------
lat_v_north_ID = netcdf.defVar(ncid,'lat_v_north','double',[xi_v_ID]);
netcdf.putAtt(ncid,lat_v_north_ID,'long_name','latitute of V-points, northern boundary condition')
netcdf.putAtt(ncid,lat_v_north_ID,'units','degree_north')
netcdf.putAtt(ncid,lat_v_north_ID,'standard_name','latitude')
%--------------------------------------------------------------------------
bry_time_ID = netcdf.defVar(ncid,'bry_time','double',bry_time1_ID);
netcdf.putAtt(ncid,bry_time_ID,'long_name','time for ocean boundary variables')
netcdf.putAtt(ncid,bry_time_ID,'units','days since 2005-01-01 00:00:00')
netcdf.putAtt(ncid,bry_time_ID,'calendar','365.0 days in every year')
%--------------------------------------------------------------------------
ocean_time_ID = netcdf.defVar(ncid,'ocean_time','double',ocean_time1_ID);
netcdf.putAtt(ncid,ocean_time_ID,'long_name','time for ocean boundary variables')
netcdf.putAtt(ncid,ocean_time_ID,'units','days since 2005-01-01 00:00:00')
netcdf.putAtt(ncid,ocean_time_ID,'calendar','365.0 days in every year')
% %--------------------------------------------------------------------------
zeta_west_ID = netcdf.defVar(ncid,'zeta_west','double',[eta_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,zeta_west_ID,'long_name','free-surface, western boundary condition')
netcdf.putAtt(ncid,zeta_west_ID,'units','meter')
netcdf.putAtt(ncid,zeta_west_ID,'time','bry_time')
netcdf.putAtt(ncid,zeta_west_ID,'coordinates','lon_rho_west lat_rho_west bry_time')
% %--------------------------------------------------------------------------
zeta_east_ID = netcdf.defVar(ncid,'zeta_east','double',[eta_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,zeta_east_ID,'long_name','free-surface, eastern boundary condition')
netcdf.putAtt(ncid,zeta_east_ID,'units','meter')
netcdf.putAtt(ncid,zeta_east_ID,'time','bry_time')
netcdf.putAtt(ncid,zeta_east_ID,'coordinates','lon_rho_east lat_rho_east bry_time')
% %--------------------------------------------------------------------------
zeta_south_ID = netcdf.defVar(ncid,'zeta_south','double',[xi_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,zeta_south_ID,'long_name','free-surface, southern boundary condition')
netcdf.putAtt(ncid,zeta_south_ID,'units','meter')
netcdf.putAtt(ncid,zeta_south_ID,'time','bry_time')
netcdf.putAtt(ncid,zeta_south_ID,'coordinates','lon_rho_south lat_rho_south bry_time')
% %--------------------------------------------------------------------------
zeta_north_ID = netcdf.defVar(ncid,'zeta_north','double',[xi_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,zeta_north_ID,'long_name','free-surface, northern boundary condition')
netcdf.putAtt(ncid,zeta_north_ID,'units','meter')
netcdf.putAtt(ncid,zeta_north_ID,'time','bry_time')
netcdf.putAtt(ncid,zeta_north_ID,'coordinates','lon_rho_north lat_rho_north bry_time')
% %--------------------------------------------------------------------------
ubar_west_ID = netcdf.defVar(ncid,'ubar_west','double',[eta_u_ID bry_time1_ID]);
netcdf.putAtt(ncid,ubar_west_ID,'long_name','vertically integrated u-momentum component, western boundary condition')
netcdf.putAtt(ncid,ubar_west_ID,'units','meter second-1')
netcdf.putAtt(ncid,ubar_west_ID,'time','bry_time')
netcdf.putAtt(ncid,ubar_west_ID,'coordinates','lon_u_west lat_u_west bry_time')
% %--------------------------------------------------------------------------
ubar_east_ID = netcdf.defVar(ncid,'ubar_east','double',[eta_u_ID bry_time1_ID]);
netcdf.putAtt(ncid,ubar_east_ID,'long_name','vertically integrated u-momentum component, eastern boundary condition')
netcdf.putAtt(ncid,ubar_east_ID,'units','meter second-1')
netcdf.putAtt(ncid,ubar_east_ID,'time','bry_time')
netcdf.putAtt(ncid,ubar_east_ID,'coordinates','lon_u_east lat_u_east bry_time')
% %--------------------------------------------------------------------------
ubar_south_ID = netcdf.defVar(ncid,'ubar_south','double',[xi_u_ID bry_time1_ID]);
netcdf.putAtt(ncid,ubar_south_ID,'long_name','vertically integrated u-momentum component, southern boundary condition')
netcdf.putAtt(ncid,ubar_south_ID,'units','meter second-1')
netcdf.putAtt(ncid,ubar_south_ID,'time','bry_time')
netcdf.putAtt(ncid,ubar_south_ID,'coordinates','lon_u_south lat_u_south bry_time')
% %--------------------------------------------------------------------------
ubar_north_ID = netcdf.defVar(ncid,'ubar_north','double',[xi_u_ID bry_time1_ID]);
netcdf.putAtt(ncid,ubar_north_ID,'long_name','vertically integrated u-momentum component, northern boundary condition')
netcdf.putAtt(ncid,ubar_north_ID,'units','meter second-1')
netcdf.putAtt(ncid,ubar_north_ID,'time','bry_time')
netcdf.putAtt(ncid,ubar_north_ID,'coordinates','lon_u_north lat_u_north bry_time')
% %--------------------------------------------------------------------------
vbar_west_ID = netcdf.defVar(ncid,'vbar_west','double',[eta_v_ID bry_time1_ID]);
netcdf.putAtt(ncid,vbar_west_ID,'long_name','vertically integrated v-momentum component, western boundary condition')
netcdf.putAtt(ncid,vbar_west_ID,'units','meter second-1')
netcdf.putAtt(ncid,vbar_west_ID,'time','bry_time')
netcdf.putAtt(ncid,vbar_west_ID,'coordinates','lon_v_west lat_v_west bry_time')
% %--------------------------------------------------------------------------
vbar_east_ID = netcdf.defVar(ncid,'vbar_east','double',[eta_v_ID bry_time1_ID]);
netcdf.putAtt(ncid,vbar_east_ID,'long_name','vertically integrated v-momentum component, eastern boundary condition')
netcdf.putAtt(ncid,vbar_east_ID,'units','meter second-1')
netcdf.putAtt(ncid,vbar_east_ID,'time','bry_time')
netcdf.putAtt(ncid,vbar_east_ID,'coordinates','lon_v_east lat_v_east bry_time')
% %--------------------------------------------------------------------------
vbar_south_ID = netcdf.defVar(ncid,'vbar_south','double',[xi_v_ID bry_time1_ID]);
netcdf.putAtt(ncid,vbar_south_ID,'long_name','vertically integrated v-momentum component, southern boundary condition')
netcdf.putAtt(ncid,vbar_south_ID,'units','meter second-1')
netcdf.putAtt(ncid,vbar_south_ID,'time','bry_time')
netcdf.putAtt(ncid,vbar_south_ID,'coordinates','lon_v_south lat_v_south bry_time')
% %--------------------------------------------------------------------------
vbar_north_ID = netcdf.defVar(ncid,'vbar_north','double',[xi_v_ID bry_time1_ID]);
netcdf.putAtt(ncid,vbar_north_ID,'long_name','vertically integrated v-momentum component, northern boundary condition')
netcdf.putAtt(ncid,vbar_north_ID,'units','meter second-1')
netcdf.putAtt(ncid,vbar_north_ID,'time','bry_time')
netcdf.putAtt(ncid,vbar_north_ID,'coordinates','lon_v_north lat_v_north bry_time')
% %--------------------------------------------------------------------------
% u_ID = netcdf.defVar(ncid,'u','double',[xi_u_ID eta_u_ID s_rho1_ID bry_time1_ID]);
% netcdf.putAtt(ncid,u_ID,'long_name','u-momentum component')
% netcdf.putAtt(ncid,u_ID,'units','meter second-1')
% netcdf.putAtt(ncid,u_ID,'time','ocean_time')
% netcdf.putAtt(ncid,u_ID,'coordinates','lon_u lat_u s_rho ocean_time')
% %--------------------------------------------------------------------------
% v_ID = netcdf.defVar(ncid,'v','double',[xi_v_ID eta_v_ID s_rho1_ID bry_time1_ID]);
% netcdf.putAtt(ncid,v_ID,'long_name','v-momentum component')
% netcdf.putAtt(ncid,v_ID,'units','meter second-1')
% netcdf.putAtt(ncid,v_ID,'time','ocean_time')
% netcdf.putAtt(ncid,v_ID,'coordinates','lon_v lat_v s_rho ocean_time')
% %--------------------------------------------------------------------------
temp_west_ID = netcdf.defVar(ncid,'temp_west','double',[eta_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,temp_west_ID,'long_name','potential temperature, western boundary condition')
netcdf.putAtt(ncid,temp_west_ID,'units','Celsius')
netcdf.putAtt(ncid,temp_west_ID,'time','ocean_time')
netcdf.putAtt(ncid,temp_west_ID,'coordinates','lon_rho lat_rho s_rho ocean_time')
% %--------------------------------------------------------------------------
temp_east_ID = netcdf.defVar(ncid,'temp_east','double',[eta_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,temp_east_ID,'long_name','potential temperature, eastern boundary condition')
netcdf.putAtt(ncid,temp_east_ID,'units','Celsius')
netcdf.putAtt(ncid,temp_east_ID,'time','bry_time')
netcdf.putAtt(ncid,temp_east_ID,'coordinates','lon_rho_east lat_rho_east s_rho bry_time')
% %--------------------------------------------------------------------------
temp_south_ID = netcdf.defVar(ncid,'temp_south','double',[xi_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,temp_south_ID,'long_name','potential temperature, southern boundary condition')
netcdf.putAtt(ncid,temp_south_ID,'units','Celsius')
netcdf.putAtt(ncid,temp_south_ID,'time','bry_time')
netcdf.putAtt(ncid,temp_south_ID,'coordinates','lon_rho_east lat_rho_east s_rho bry_time')
% %--------------------------------------------------------------------------
temp_north_ID = netcdf.defVar(ncid,'temp_north','double',[xi_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,temp_north_ID,'long_name','potential temperature, northern boundary condition')
netcdf.putAtt(ncid,temp_north_ID,'units','Celsius')
netcdf.putAtt(ncid,temp_north_ID,'time','bry_time')
netcdf.putAtt(ncid,temp_north_ID,'coordinates','lon_rho_east lat_rho_east s_rho bry_time')
% %--------------------------------------------------------------------------
salt_west_ID = netcdf.defVar(ncid,'salt_west','double',[eta_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,salt_west_ID,'long_name','salinity, western boundary condition')
netcdf.putAtt(ncid,salt_west_ID,'time','bry_time')
netcdf.putAtt(ncid,salt_west_ID,'coordinates','lon_rho_west lat_rho_west s_rho bry_time')
% %--------------------------------------------------------------------------
salt_east_ID = netcdf.defVar(ncid,'salt_east','double',[eta_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,salt_east_ID,'long_name','salinity, eastern boundary condition')
netcdf.putAtt(ncid,salt_east_ID,'time','bry_time')
netcdf.putAtt(ncid,salt_east_ID,'coordinates','lon_rho_east lat_rho_east s_rho bry_time')
% %--------------------------------------------------------------------------
salt_south_ID = netcdf.defVar(ncid,'salt_south','double',[xi_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,salt_south_ID,'long_name','salinity, southern boundary condition')
netcdf.putAtt(ncid,salt_south_ID,'time','bry_time')
netcdf.putAtt(ncid,salt_south_ID,'coordinates','lon_rho_south lat_rho_south s_rho bry_time')
% %--------------------------------------------------------------------------
salt_north_ID = netcdf.defVar(ncid,'salt_north','double',[xi_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,salt_north_ID,'long_name','salinity, northern boundary condition')
netcdf.putAtt(ncid,salt_north_ID,'time','bry_time')
netcdf.putAtt(ncid,salt_north_ID,'coordinates','lon_rho_north lat_rho_north s_rho bry_time')
% %--------------------------------------------------------------------------
aice_west_ID = netcdf.defVar(ncid,'aice_west','double',[eta_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,aice_west_ID,'long_name','ice concentration 0-1, western boundary condition')
netcdf.putAtt(ncid,aice_west_ID,'time','bry_time')
netcdf.putAtt(ncid,aice_west_ID,'coordinates','lon_rho_west lat_rho_west bry_time')
% %--------------------------------------------------------------------------
aice_east_ID = netcdf.defVar(ncid,'aice_east','double',[eta_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,aice_east_ID,'long_name','ice concentration 0-1, eastern boundary condition')
netcdf.putAtt(ncid,aice_east_ID,'time','bry_time')
netcdf.putAtt(ncid,aice_east_ID,'coordinates','lon_rho_east lat_rho_east bry_time')
% %--------------------------------------------------------------------------
aice_south_ID = netcdf.defVar(ncid,'aice_south','double',[xi_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,aice_south_ID,'long_name','ice concentration 0-1, southern boundary condition')
netcdf.putAtt(ncid,aice_south_ID,'time','bry_time')
netcdf.putAtt(ncid,aice_south_ID,'coordinates','lon_rho_south lat_rho_south bry_time')
% %--------------------------------------------------------------------------
aice_north_ID = netcdf.defVar(ncid,'aice_north','double',[xi_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,aice_north_ID,'long_name','ice concentration 0-1, northern boundary condition')
netcdf.putAtt(ncid,aice_north_ID,'time','bry_time')
netcdf.putAtt(ncid,aice_north_ID,'coordinates','lon_rho_north lat_rho_north bry_time')
% %--------------------------------------------------------------------------
dye_west_01_ID = netcdf.defVar(ncid,'dye_west_01','double',[eta_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_west_01_ID,'long_name','CDW tracer, western boundary condition')
netcdf.putAtt(ncid,dye_west_01_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_west_01_ID,'coordinates','bry_time')
% %--------------------------------------------------------------------------
dye_east_01_ID = netcdf.defVar(ncid,'dye_east_01','double',[eta_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_east_01_ID,'long_name','CDW tracer, eastern boundary condition')
netcdf.putAtt(ncid,dye_east_01_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_east_01_ID,'coordinates','bry_time')
% %--------------------------------------------------------------------------
dye_south_01_ID = netcdf.defVar(ncid,'dye_south_01','double',[xi_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_south_01_ID,'long_name','CDW tracer, southern boundary condition')
netcdf.putAtt(ncid,dye_south_01_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_south_01_ID,'coordinates','bry_time')
%--------------------------------------------------------------------------
dye_north_01_ID = netcdf.defVar(ncid,'dye_north_01','double',[xi_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_north_01_ID,'long_name','CDW tracer, northern boundary condition')
netcdf.putAtt(ncid,dye_north_01_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_north_01_ID,'coordinates','bry_time')
% %--------------------------------------------------------------------------
dye_west_02_ID = netcdf.defVar(ncid,'dye_west_02','double',[eta_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_west_02_ID,'long_name','Sea ice melt tracer, western boundary condition')
netcdf.putAtt(ncid,dye_west_02_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_west_02_ID,'coordinates','lon_rho_west lat_rho_west s_rho bry_time')
% %--------------------------------------------------------------------------
dye_east_02_ID = netcdf.defVar(ncid,'dye_east_02','double',[eta_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_east_02_ID,'long_name','Sea ice melt tracer, eastern boundary condition')
netcdf.putAtt(ncid,dye_east_02_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_east_02_ID,'coordinates','lon_rho_east lat_rho_east s_rho bry_time')
% %--------------------------------------------------------------------------
dye_south_02_ID = netcdf.defVar(ncid,'dye_south_02','double',[xi_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_south_02_ID,'long_name','Sea ice melt tracer, southern boundary condition')
netcdf.putAtt(ncid,dye_south_02_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_south_02_ID,'coordinates','lon_rho_south lat_rho_south s_rho bry_time')
%--------------------------------------------------------------------------
dye_north_02_ID = netcdf.defVar(ncid,'dye_north_02','double',[xi_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_north_02_ID,'long_name','Sea ice melt tracer, northern boundary condition')
netcdf.putAtt(ncid,dye_north_02_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_north_02_ID,'coordinates','lon_rho_north lat_rho_north s_rho bry_time')
% %--------------------------------------------------------------------------
dye_west_03_ID = netcdf.defVar(ncid,'dye_west_03','double',[eta_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_west_03_ID,'long_name','Ice shelf melt tracer, western boundary condition')
netcdf.putAtt(ncid,dye_west_03_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_west_03_ID,'coordinates','lon_rho_west lat_rho_west bry_time')
% %--------------------------------------------------------------------------
dye_east_03_ID = netcdf.defVar(ncid,'dye_east_03','double',[eta_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_east_03_ID,'long_name','Ice shelf melt tracer, eastern boundary condition')
netcdf.putAtt(ncid,dye_east_03_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_east_03_ID,'coordinates','lon_rho_east lat_rho_east bry_time')
% %--------------------------------------------------------------------------
dye_south_03_ID = netcdf.defVar(ncid,'dye_south_03','double',[xi_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_south_03_ID,'long_name','Ice shelf melt tracer, southern boundary condition')
netcdf.putAtt(ncid,dye_south_03_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_south_03_ID,'coordinates','lon_rho_south lat_rho_south bry_time')
%--------------------------------------------------------------------------
dye_north_03_ID = netcdf.defVar(ncid,'dye_north_03','double',[xi_rho_ID s_rho_ID bry_time1_ID]);
netcdf.putAtt(ncid,dye_north_03_ID,'long_name','Ice shelf melt tracer, northern boundary condition')
netcdf.putAtt(ncid,dye_north_03_ID,'time','bry_time')
netcdf.putAtt(ncid,dye_north_03_ID,'coordinates','lon_rho_north lat_rho_north bry_time')
%--------------------------------------------------------------------------
% --- end define mode ---
netcdf.endDef(ncid)
%
% --- fill Variables ---
disp('    => Filling Variables...')
% 
%--------------------------------------------------------------------------
disp('  Generating boundary data ...');
bryvarfilename='F:\Ross_amundsen_roms_model\boundary_file\C_RAS_model_boundary_files\32layer\RAS_bry_2005.mat';
load(bryvarfilename);
ocean_time=bry_time;
netcdf.putVar(ncid,spherical_ID,spherical);
netcdf.putVar(ncid,Vtransform_ID,Vtransform);
netcdf.putVar(ncid,Vstretching_ID,Vstretching);
netcdf.putVar(ncid,theta_s_ID,theta_s);
netcdf.putVar(ncid,theta_b_ID,theta_b);
netcdf.putVar(ncid,Tcline_ID,Tcline);
netcdf.putVar(ncid,hc_ID,hc);
netcdf.putVar(ncid,s_rho1_ID,s_rho);
netcdf.putVar(ncid,s_w1_ID,s_w);
netcdf.putVar(ncid,Cs_r_ID,Cs_r);
netcdf.putVar(ncid,Cs_w_ID,Cs_w);
netcdf.putVar(ncid,lon_rho_west_ID,lon_rho_west);
netcdf.putVar(ncid,lat_rho_west_ID,lat_rho_west);
netcdf.putVar(ncid,lon_rho_east_ID,lon_rho_east);
netcdf.putVar(ncid,lat_rho_east_ID,lat_rho_east);
netcdf.putVar(ncid,lon_rho_south_ID,lon_rho_south);
netcdf.putVar(ncid,lat_rho_south_ID,lat_rho_south);
netcdf.putVar(ncid,lon_rho_north_ID,lon_rho_north);
netcdf.putVar(ncid,lat_rho_north_ID,lat_rho_north);
netcdf.putVar(ncid,lon_u_west_ID,lon_u_west);
netcdf.putVar(ncid,lat_u_west_ID,lat_u_west);
netcdf.putVar(ncid,lon_u_east_ID,lon_u_east);
netcdf.putVar(ncid,lat_u_east_ID,lat_u_east);
netcdf.putVar(ncid,lon_u_south_ID,lon_u_south);
netcdf.putVar(ncid,lat_u_south_ID,lat_u_south);
netcdf.putVar(ncid,lon_u_north_ID,lon_u_north);
netcdf.putVar(ncid,lat_u_north_ID,lat_u_north);
netcdf.putVar(ncid,lon_v_west_ID,lon_v_west);
netcdf.putVar(ncid,lat_v_west_ID,lat_v_west);
netcdf.putVar(ncid,lon_v_east_ID,lon_v_east);
netcdf.putVar(ncid,lat_v_east_ID,lat_v_east);
netcdf.putVar(ncid,lon_v_south_ID,lon_v_south);
netcdf.putVar(ncid,lat_v_south_ID,lat_v_south);
netcdf.putVar(ncid,lon_v_north_ID,lon_v_north);
netcdf.putVar(ncid,lat_v_north_ID,lat_v_north);
netcdf.putVar(ncid,bry_time_ID,bry_time);
netcdf.putVar(ncid,ocean_time_ID,ocean_time);
netcdf.putVar(ncid,zeta_west_ID,zeta_west_bry);
netcdf.putVar(ncid,zeta_east_ID,zeta_east_bry);
netcdf.putVar(ncid,zeta_south_ID,zeta_south_bry);
netcdf.putVar(ncid,zeta_north_ID,zeta_north_bry);
netcdf.putVar(ncid,ubar_west_ID,ubar_west_bry);
netcdf.putVar(ncid,ubar_east_ID,ubar_east_bry);
netcdf.putVar(ncid,ubar_south_ID,ubar_south_bry);
netcdf.putVar(ncid,ubar_north_ID,ubar_north_bry);
netcdf.putVar(ncid,vbar_west_ID,vbar_west_bry);
netcdf.putVar(ncid,vbar_east_ID,vbar_east_bry);
netcdf.putVar(ncid,vbar_south_ID,vbar_south_bry);
netcdf.putVar(ncid,vbar_north_ID,vbar_north_bry);
% netcdf.putVar(ncid,u_ID,u_bry);
% netcdf.putVar(ncid,v_ID,v_bry);
netcdf.putVar(ncid,temp_west_ID,temp_west_bry);
netcdf.putVar(ncid,temp_east_ID,temp_east_bry);
netcdf.putVar(ncid,temp_south_ID,temp_south_bry);
netcdf.putVar(ncid,temp_north_ID,temp_north_bry);
netcdf.putVar(ncid,salt_west_ID,salt_west_bry);
netcdf.putVar(ncid,salt_east_ID,salt_east_bry);
netcdf.putVar(ncid,salt_south_ID,salt_south_bry);
netcdf.putVar(ncid,salt_north_ID,salt_north_bry);
netcdf.putVar(ncid,aice_west_ID,aice_west_bry);
netcdf.putVar(ncid,aice_east_ID,aice_east_bry);
netcdf.putVar(ncid,aice_south_ID,aice_south_bry);
netcdf.putVar(ncid,aice_north_ID,aice_north_bry);
netcdf.putVar(ncid,dye_west_01_ID,dye_west_01_bry);
netcdf.putVar(ncid,dye_east_01_ID,dye_east_01_bry);
netcdf.putVar(ncid,dye_south_01_ID,dye_south_01_bry);
netcdf.putVar(ncid,dye_north_01_ID,dye_north_01_bry);
netcdf.putVar(ncid,dye_west_02_ID,dye_west_02_bry);
netcdf.putVar(ncid,dye_east_02_ID,dye_east_02_bry);
netcdf.putVar(ncid,dye_south_02_ID,dye_south_02_bry);
netcdf.putVar(ncid,dye_north_02_ID,dye_north_02_bry);
netcdf.putVar(ncid,dye_west_03_ID,dye_west_03_bry);
netcdf.putVar(ncid,dye_east_03_ID,dye_east_03_bry);
netcdf.putVar(ncid,dye_south_03_ID,dye_south_03_bry);
netcdf.putVar(ncid,dye_north_03_ID,dye_north_03_bry);
% ----------------- close file ------------------
netcdf.close(ncid);
% 
disp('  Done !');
